@@ -54,7 +54,6 @@ import java.util.Arrays;
 import java.util.Collection;
 import java.util.Collections;
 import java.util.HashMap;
-import java.util.HashSet;
 import java.util.List;
 import java.util.Map;
 import java.util.Set;
@@ -63,6 +62,7 @@ import org.json.JSONArray;
 import org.json.JSONException;
 import org.json.JSONObject;
 import org.json.JSONValue;
+import com.google.common.collect.ImmutableSet;
 import com.openexchange.ajax.requesthandler.AJAXRequestData;
 import com.openexchange.config.ConfigurationService;
 import com.openexchange.exception.OXException;
@@ -95,7 +95,7 @@ public abstract class AbstractSubscribeAction extends AbstractSubscribeSourcesAc
     }
 
     /** The set of known parameter names */
-    protected static final Set<String> KNOWN_PARAMS = Collections.unmodifiableSet(new HashSet<String>(Arrays.asList("folder", "columns", "session", "action")));
+    protected static final Set<String> KNOWN_PARAMS = ImmutableSet.of("folder", "columns", "session", "action");
 
     protected Subscription getSubscription(final AJAXRequestData requestData, final ServerSession session, final String secret) throws JSONException, OXException {
         final JSONObject object = (JSONObject) requestData.requireData();
@@ -106,17 +106,6 @@ public abstract class AbstractSubscribeAction extends AbstractSubscribeSourcesAc
         return subscription;
     }
 
-    /**
-     * Checks if the user has the permission to see the given {@link Subscription}
-     *
-     * @param session The users session
-     * @param sub The {@link Subscription} to check
-     * @return <code>true</code> if the user is allowed to see the subscription, <code>false</code> otherwise
-     */
-    protected boolean checkPermission(ServerSession session, Subscription sub) {
-        return sub.containsUserId() ? session.getUserId() == sub.getUserId() : false;
-    }
-
     protected SubscriptionSourceDiscoveryService getDiscovery(final ServerSession session) throws OXException {
         return services.getService(SubscriptionSourceDiscoveryService.class).filter(session.getUserId(), session.getContextId());
     }
